"From: https://github.com/bazelbuild/rules_nodejs/blob/master/examples/jest/jest.bzl"

load("@npm//jest-cli:index.bzl", "jest", _jest_test = "jest_test")

def jest_test(name, srcs, deps, size = "medium", jest_config = "//:jest.config.js", snapshots = [], flaky = False, **kwargs):
    """A macro around the autogenerated jest_test rule.

    Args:
        name: target name
        srcs: list of tests, srcs & snapshot files
        deps: npm deps
        size: test size
        snapshots: snapshot files
        jest_config: jest.config.js file, default to the root one
        flaky: Whether this test is flaky
        **kwargs: the rest
    """
    templated_args = [
        "--no-cache",
        "--no-watchman",
        "--ci",
        "--runInBand",
        "--colors",
    ]
    templated_args.extend(["--config", "$(rootpath %s)" % jest_config])
    for src in srcs:
        templated_args.extend(["--runTestsByPath", "$(rootpath %s)" % src])

    data = [jest_config] + srcs + snapshots + deps + [
        "@npm//@jest/transform",
        "@npm//ts-jest",
        "@npm//@types/jest",
        "@npm//tslib",
        "//:tsconfig.json",
        "//tools:jest-reporter.js",
    ]

    _jest_test(
        name = name,
        data = data,
        templated_args = templated_args,
        tags = [
            # Need to set the pwd to avoid jest needing a runfiles helper
            # Windows users with permissions can use --enable_runfiles
            # to make this test work
            "no-bazelci-windows",
            # TODO: why does this fail almost all the time, but pass on local Mac?
            "no-bazelci-mac",
        ],
        size = size,
        flaky = flaky,
        **kwargs
    )

    # This target is used to update the snapshot
    # e.g bazel run //packages/react-intl:unit.update
    jest(
        name = "%s.update" % name,
        data = data,
        templated_args = templated_args + ["-u"],
        tags = [
            # Need to set the pwd to avoid jest needing a runfiles helper
            # Windows users with permissions can use --enable_runfiles
            # to make this test work
            "no-bazelci-windows",
            # TODO: why does this fail almost all the time, but pass on local Mac?
            "no-bazelci-mac",
        ],
        **kwargs
    )
